@@ -36,7 +36,7 @@
 #'   cost matrix.
 #' @param boot (default `FALSE`) Logical that sets whether or not to perform
 #'   bootstrapping of the OT indices.
-#' @param stratified_boot (default `FALSE`) Logical that sets the type of
+#' @param stratified_boot (default `TRUE`) Logical that sets the type of
 #'   resampling performed. With `stratified_boot=FALSE`, the function resamples
 #'   the dataset and then creates the partitions. Otherwise, first, it
 #'   creates the partitions and then it performs stratified bootstrapping with
@@ -163,7 +163,7 @@ ot_indices <- function(x,
                        solver_optns = NULL,
                        scaling = TRUE,
                        boot = FALSE,
-                       stratified_boot = FALSE,
+                       stratified_boot = TRUE,
                        R = NULL,
                        parallel = "no",
                        ncpus = 1,
@@ -193,7 +193,7 @@ ot_indices <- function(x,
   if (!is.logical(scaling)) stop("`scaling` should be logical")
 
   # Check if the solver is present in the pool
-  match.arg(solver, c("sinkhorn", "sinkhorn_log", "transport"))
+  match.arg(solver, c("sinkhorn", "sinkhorn_stable", "transport"))
 
   # Check that bootstrapping is correctly set
   if ((!boot & !is.null(R)) | (boot & is.null(R))) {
@@ -270,7 +270,7 @@ ot_indices <- function(x,
   solver_fun <- switch (
     solver,
     "sinkhorn" = sinkhorn,
-    "sinkhorn_log" = sinkhorn_log,
+    "sinkhorn_stable" = sinkhorn_stable,
     "transport" = transport::transport,
     default = NULL
   )
@@ -286,10 +286,11 @@ ot_indices <- function(x,
   if (boot) {
     V <- array(dim = K)
     W_ci <- data.frame(matrix(nrow = K,
-                              ncol = 3,
+                              ncol = 5,
                               dimnames = list(NULL,
-                                              c("Inputs", "low.ci", "high.ci"))))
-    W_ci$Inputs <- names(W)
+                                              c("input", "original", "bias",
+                                                "low.ci", "high.ci"))))
+    W_ci$input <- names(W)
     IS_ci <- list()
     V_ci <- list()
   }
@@ -379,10 +380,11 @@ ot_indices <- function(x,
       W_stats <- bootstats(W_boot, type = type, conf = conf)
 
       # Save the results
-      W[k] <- W_stats$original[1]
-      IS[[k]] <- matrix(W_stats$original[2:(M + 1)], nrow = 1)
-      V[k] <- W_stats$original[M + 2]
-      W_ci[k, 2:3] <- c(W_stats$low.ci[1], W_stats$high.ci[1])
+      W[k] <- W_stats$index[1]
+      IS[[k]] <- matrix(W_stats$index[2:(M + 1)], nrow = 1)
+      V[k] <- W_stats$index[M + 2]
+      W_ci[k, 2:5] <- c(W_stats$original[1], W_stats$bias[1],
+                        W_stats$low.ci[1], W_stats$high.ci[1])
       IS_ci[[k]] <- cbind(W_stats$low.ci[2:(M + 1)], W_stats$high.ci[2:(M + 1)])
       V_ci[[k]] <- cbind(W_stats$low.ci[M + 2], W_stats$high.ci[M + 2])
     }
